
pro fiss_cal_par, calfile, flatfile,   darkfile, slit_pattern,  tilt,  wvpar,  dw
;+
;
;      ouputs:
;         slit_pattern    an image of slit pattern (input or output)
;         tilt     set to a named variable containing tilt value (input or output)
;         wvpar    wavelength parameters coming out of fiss_wv_calib (input or output)
;         dw       set to a named variable containing values of horizonal deviation
;                  of a line (input or output)

;
;
;   Remarks:
;
;   Required routines: fiss_sp_av, fiss_slit_pattern, fiss_get_dw, fiss_wv_calib
;                           piecewise_quadratic_fit
;   History:
;         2010 July,  first coded  (J. Chae)
;
;-
h=headfits(calfile) & nx=fxpar(h, 'NAXIS3') & ny=fxpar(h,'NAXIS2') & nw=fxpar(h, 'NAXIS1')
if darkfile eq '' then dark=0. else dark=readfits(darkfile, /sil)
av= (fiss_sp_av(calfile)-dark)/readfits(flatfile, /sil)
slit_pattern=fiss_slit_pattern(av, tilt)
slit_pattern=slit_pattern/median(slit_pattern)
av=av/slit_pattern
av1=rot(av, tilt, /interp)
refsp=total(av1[*,ny/2-5:ny/2+5],2)
fiss_wv_calib, strmid(fxpar(h, 'wavelen'),0,4), refsp, wvpar
dw1 = fiss_get_dw(av1, refsp)
y=findgen(ny)
ay=total(av1, 2)
piecewise_quadratic_fit, y, dw1, dw, npoint=30, sel=ay ge median(ay, 30)*0.5
end